==> igniteui-react-layouts-18.0.0.tgz: package/esm5/lib/igr-tool-action-performed-event-args.js <==
import { IgrToolActionEventDetail } from "./igr-tool-action-event-detail";
import { IgrToolActionEventDetailCollection } from "./igr-tool-action-event-detail-collection";
import { ToolActionPerformedEventArgs as ToolActionPerformedEventArgs_internal } from "./ToolActionPerformedEventArgs";
import { ensureBool } from "igniteui-react-core";
import { ToolActionEventDetailCollection as ToolActionEventDetailCollection_internal } from "./ToolActionEventDetailCollection";
import { ToolActionEventDetail } from "./ToolActionEventDetail";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
var IgrToolActionPerformedEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrToolActionPerformedEventArgs() {
        this._detailCollection = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrToolActionPerformedEventArgs.prototype.createImplementation = function () {
        return new ToolActionPerformedEventArgs_internal();
    };
    Object.defineProperty(IgrToolActionPerformedEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrToolActionPerformedEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrToolActionPerformedEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrToolActionPerformedEventArgs.prototype, "isAggregate", {
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionPerformedEventArgs.prototype, "detail", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            if (!this.i.a.externalObject) {
                var e = new IgrToolActionEventDetail();
                e._implementation = this.i.a;
                this.i.a.externalObject = e;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionPerformedEventArgs.prototype, "detailCollection", {
        get: function () {
            if (this._detailCollection === null) {
                var coll = new IgrToolActionEventDetailCollection();
                var innerColl = this.i.b;
                if (!innerColl) {
                    innerColl = new ToolActionEventDetailCollection_internal();
                }
                this._detailCollection = coll._fromInner(innerColl);
                this.i.b = innerColl;
            }
            return this._detailCollection;
        },
        set: function (v) {
            if (this._detailCollection !== null) {
                this._detailCollection._setSyncTarget(null);
                this._detailCollection = null;
            }
            var coll = new IgrToolActionEventDetailCollection();
            this._detailCollection = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(ToolActionEventDetail.$type);
            var innerColl = this.i.b;
            if (!innerColl) {
                innerColl = new ToolActionEventDetailCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._detailCollection._setSyncTarget(syncColl);
            this.i.b = innerColl;
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionPerformedEventArgs;
}());
export { IgrToolActionPerformedEventArgs };

==> igniteui-react-layouts-18.1.0.tgz: package/esm5/lib/igr-tool-action-performed-event-args.js <==
import { IgrToolActionEventDetail } from "./igr-tool-action-event-detail";
import { IgrToolActionEventDetailCollection } from "./igr-tool-action-event-detail-collection";
import { ToolActionPerformedEventArgs as ToolActionPerformedEventArgs_internal } from "./ToolActionPerformedEventArgs";
import { ensureBool } from "igniteui-react-core";
import { ToolActionEventDetailCollection as ToolActionEventDetailCollection_internal } from "./ToolActionEventDetailCollection";
import { ToolActionEventDetail } from "./ToolActionEventDetail";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
var IgrToolActionPerformedEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrToolActionPerformedEventArgs() {
        this._detailCollection = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrToolActionPerformedEventArgs.prototype.createImplementation = function () {
        return new ToolActionPerformedEventArgs_internal();
    };
    Object.defineProperty(IgrToolActionPerformedEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrToolActionPerformedEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrToolActionPerformedEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrToolActionPerformedEventArgs.prototype, "isAggregate", {
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionPerformedEventArgs.prototype, "detail", {
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrToolActionEventDetail();
                if (e.i.setNativeElement) {
                    e.i.setNativeElement(r);
                }
                else {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionPerformedEventArgs.prototype, "detailCollection", {
        get: function () {
            if (this._detailCollection === null) {
                var coll = new IgrToolActionEventDetailCollection();
                var innerColl = this.i.b;
                if (!innerColl) {
                    innerColl = new ToolActionEventDetailCollection_internal();
                }
                this._detailCollection = coll._fromInner(innerColl);
                this.i.b = innerColl;
            }
            return this._detailCollection;
        },
        set: function (v) {
            if (this._detailCollection !== null) {
                this._detailCollection._setSyncTarget(null);
                this._detailCollection = null;
            }
            var coll = new IgrToolActionEventDetailCollection();
            this._detailCollection = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(ToolActionEventDetail.$type);
            var innerColl = this.i.b;
            if (!innerColl) {
                innerColl = new ToolActionEventDetailCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._detailCollection._setSyncTarget(syncColl);
            this.i.b = innerColl;
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionPerformedEventArgs;
}());
export { IgrToolActionPerformedEventArgs };
